﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Mediachase.Search.Providers.Solr35
{
    public interface IFacetFieldResponse
    {
        string Field { get; }
        string Value { get; }
        int Count { get; }
    }

    public interface IFacetQueryResponse
    {
        string Query { get; }
        int Count { get; }
    }

    /// <summary>
    /// Stores a faceting request description, exposes the resulting processed facet requests,
    /// and builds a response from the returned facet counts.
    /// </summary>
    public interface IFacetManager
    {
        /// <summary>
        /// An enumeration of fields to facet on.
        /// </summary>
        IEnumerable<string> FacetFields { get; }

        /// <summary>
        /// An enumeration of queries to facet on.
        /// </summary>
        IEnumerable<string> FacetQueries { get; }

        /// <summary>
        /// Builds a facet response suitable for inclusion in a <see cref="Mediachase.Search.ISearchResults"/> object.
        /// </summary>
        /// <param name="fieldCounts">An enumeration of counts for field facets.</param>
        /// <param name="queryCounts">An enumeration of counts for query facets.</param>
        /// <param name="locale">The locale that the search was requested for.</param>
        /// <param name="specifiedValuesOnly">
        /// If true, only values explicitly included for field facets will be included in the response.
        /// If false, field facets will return all values with a count greater than 0.
        /// </param>
        /// <returns>An enumeration of <see cref="Mediachase.Search.ISearchFacetGroup"/> object representing the facet results.</returns>
        IEnumerable<ISearchFacetGroup> BuildResponse(
            IEnumerable<IFacetFieldResponse> fieldCounts,
            IEnumerable<IFacetQueryResponse> queryCounts,
            string locale,
            bool specifiedValuesOnly);
    }
}
