﻿using System.Collections.Generic;
using System.Collections.Specialized;
using System.Linq;
using System.Text;

namespace Mediachase.Search.Providers.Solr35.Select
{
    internal class ListQuery : QueryPart
    {
        string fieldName;
        List<string> values;

        public ListQuery(string fieldName, StringCollection values)
            : this(fieldName, values.Cast<string>()) { }

        public ListQuery(string fieldName, IEnumerable<string> values)
        {
            this.fieldName = fieldName;
            this.values = values.Where(s => !string.IsNullOrEmpty(s)).Select(s => SolrSearchQueryBuilder.EscapeValueString(s)).ToList();
        }

        public override bool HasContent()
        {
            return values.Count > 0;
        }

        public override void AppendTo(StringBuilder builder)
        {
            if (values.Count == 1)
            {
                builder.Append(fieldName).Append(':').Append(values[0]);
            }
            else if (values.Count > 1)
            {
                builder.Append('(').Append(fieldName).Append(':').Append(values[0]);
                for (int i = 1; i < values.Count; ++i)
                {
                    builder.Append(" OR ").Append(fieldName).Append(':').Append(values[i]);
                }
                builder.Append(')');
            }
        }
    }
}
