﻿using System.Text;

namespace Mediachase.Search.Providers.Solr35.Select
{
    internal class RangeQuery : QueryPart
    {
        private string fieldName;
        private string fromValue, toValue, excludeValue;
        private bool inclusive;

        public RangeQuery(string fieldName, string fromValue, string toValue)
            : this(fieldName, fromValue, toValue, true, true) { }

        public RangeQuery(string fieldName, string fromValue, string toValue, bool includeFromValue, bool includeToValue)
        {
            this.fieldName = fieldName;

            if (includeFromValue == includeToValue) this.inclusive = includeFromValue;
            else if (string.IsNullOrEmpty(fromValue)) this.inclusive = includeToValue;
            else if (string.IsNullOrEmpty(toValue)) this.inclusive = includeFromValue;
            else
            {
                this.inclusive = true;
                this.excludeValue = includeFromValue ? toValue : fromValue;
            }

            this.fromValue = string.IsNullOrEmpty(fromValue) ? "*" : fromValue;
            this.toValue = string.IsNullOrEmpty(toValue) ? "*" : toValue;
        }

        public override bool HasContent()
        {
            return true;
        }

        public override void AppendTo(StringBuilder builder)
        {
            if (excludeValue != null) builder.Append("(");

            builder.Append(fieldName).Append(':')
                .Append(inclusive ? '[' : '{')
                .Append(fromValue)
                .Append(" TO ")
                .Append(toValue)
                .Append(inclusive ? ']' : '}');

            if (excludeValue != null) builder
                .Append(" -")
                .Append(fieldName)
                .Append(':')
                .Append(excludeValue)
                .Append(')');
        }
    }
}
