﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Mediachase.Search.Extensions;
using Mediachase.Commerce;

namespace Mediachase.Search.Providers.Solr35.Select
{
    /// <summary>
    /// Wrapper for CatalogEntrySearchCriteria with additional DisableDateFilter setting.
    /// </summary>
    /// <remarks>
    /// This is a bit of a hack, but allows the addition of the DisableDateFitler setting
    /// without violating the search provider API.
    /// </remarks>
    internal class SolrCatalogEntrySearchCriteria : ISearchCriteria
    {
        public CatalogEntrySearchCriteria BaseCriteria { get; private set; }

        public bool DisableDateFilter { get; private set; }

        public SolrCatalogEntrySearchCriteria(CatalogEntrySearchCriteria criteria, bool disableDateFilter)
        {
            this.BaseCriteria = criteria;
            this.DisableDateFilter = disableDateFilter;
        }

        #region ISearchCriteria Implementation

        // All ISearchCritera implementation redirects the call to the Backing object.

        public SearchFilter[] Filters { get { return BaseCriteria.Filters; }}
        public ISearchFilterValue[] ActiveFilterValues { get { return BaseCriteria.ActiveFilterValues; } }
        public string[] ActiveFilterFields { get { return BaseCriteria.ActiveFilterFields; } }
        public string Scope { get { return BaseCriteria.Scope; }  } 
        public string KeyField { get { return BaseCriteria.KeyField; }  }
        public string CacheKey { get { return BaseCriteria.CacheKey; }  }

        public SearchSort Sort
        {
            get { return BaseCriteria.Sort; }
            set { BaseCriteria.Sort = value; }
        }

        public string Locale
        {
            get { return BaseCriteria.Locale; }
            set { BaseCriteria.Locale = value; }
        }

        public Currency Currency
        {
            get { return BaseCriteria.Currency; }
            set { BaseCriteria.Currency = value; }
        }

        public MarketId MarketId
        {
            get { return BaseCriteria.MarketId; }
            set { BaseCriteria.MarketId = value; }
        }

        public int StartingRecord
        {
            get { return BaseCriteria.StartingRecord; }
            set { BaseCriteria.StartingRecord = value; }
        }

        public int RecordsToRetrieve
        {
            get { return BaseCriteria.RecordsToRetrieve; }
            set { BaseCriteria.RecordsToRetrieve = value; }
        }

        public void Add(SearchFilter filter)
        {
            BaseCriteria.Add(filter);
        }
        
        public void Add(string field, ISearchFilterValue value)
        {
            BaseCriteria.Add(field, value);
        }

        public virtual bool IgnoreFilterOnLanguage 
        { 
            get { return BaseCriteria.IgnoreFilterOnLanguage; }
            set { BaseCriteria.IgnoreFilterOnLanguage = value; }
        }


        public virtual bool IncludeInactive
        {
            get { return BaseCriteria.IncludeInactive; }
            set { BaseCriteria.IncludeInactive = value; }
        }

        #endregion
    }
}
